@@ -3,10 +3,10 @@
 {-# OPTIONS_GHC -fno-warn-deprecations #-}
 {-|
 Module      :  HsLua.Core.RunTests
-Copyright   :  © 2017-2022 Albert Krewinkel
+Copyright   :  © 2017-2026 Albert Krewinkel
 License     :  MIT
 
-Maintainer  :  Albert Krewinkel <tarleb+hslua@zeitkraut.de>
+Maintainer  :  Albert Krewinkel <tarleb@hslua.org>
 Stability   :  stable
 Portability :  portable
 
